@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py,v 1.52 2006/07/14 18:09:02 wwalker Exp $"
-__version__   = "$Revision: 1.52 $"
-__date__      = "$Date: 2006/07/14 18:09:02 $"
+__id__        = "$Id: braillegenerator.py 1330 2006-08-17 16:15:03Z richb $"
+__version__   = "$Revision: 1330 $"
+__date__      = "$Date: 2006-08-17 12:15:03 -0400 (Thu, 17 Aug 2006) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -34,7 +34,7 @@ import math
 import atspi
 import braille
 import debug
-import orca
+import orca_state
 import rolenames
 import settings
 import util
@@ -405,7 +405,7 @@ class BrailleGenerator:
         else:
             text = util.appendString(text, "< >")
 
-        if obj == orca.locusOfFocus:
+        if obj == orca_state.locusOfFocus:
             text = util.appendString(text, self._getTextForRole(obj))
             text = util.appendString(text, self._getTextForAvailability(obj))
             text = util.appendString(text,
@@ -461,6 +461,13 @@ class BrailleGenerator:
             regions.append(braille.Region(
                 " " + rolenames.getBrailleForRoleName(obj)))
 
+        # Things may not have gone as expected above, so we'll do some
+        # defensive programming to make sure we don't get an index out
+        # of bounds.
+        #
+        if focusedRegionIndex >= len(regions):
+            focusedRegionIndex = 0
+
         # [[[TODO: WDW - perhaps if a text area was created, we should
         # give focus to it.]]]
         #
@@ -645,7 +652,7 @@ class BrailleGenerator:
         text = util.appendString(text, util.getDisplayedText(obj))
         text = util.appendString(text, rolenames.getBrailleForRoleName(obj))
 
-        if obj == orca.locusOfFocus:
+        if obj == orca_state.locusOfFocus:
             text = util.appendString(text, self._getTextForAvailability(obj))
             text = util.appendString(text,
                                       self._getTextForAccelerator(obj),
@@ -687,7 +694,7 @@ class BrailleGenerator:
         text = util.appendString(text, util.getDisplayedLabel(obj))
         text = util.appendString(text, util.getDisplayedText(obj))
 
-        if obj == orca.locusOfFocus:
+        if obj == orca_state.locusOfFocus:
             text = util.appendString(text, self._getTextForAvailability(obj))
             text = util.appendString(text,
                                       self._getTextForAccelerator(obj),
@@ -753,7 +760,7 @@ class BrailleGenerator:
         text = util.appendString(text, util.getDisplayedLabel(obj))
         text = util.appendString(text, util.getDisplayedText(obj))
 
-        if obj == orca.locusOfFocus:
+        if obj == orca_state.locusOfFocus:
             text = util.appendString(text, self._getTextForAvailability(obj))
             text = util.appendString(text,
                                       self._getTextForAccelerator(obj),
@@ -811,7 +818,6 @@ class BrailleGenerator:
         text = ""
         text = util.appendString(text, util.getDisplayedLabel(obj))
         text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, self._getTextForRole(obj))
 
         # In Java, some push buttons don't have label and text.
         # In this case, we'll add to presentation the object description,
@@ -820,6 +826,8 @@ class BrailleGenerator:
         if (not text) and (obj.description):
             text = util.appendString(text, obj.description)
 
+        text = util.appendString(text, self._getTextForRole(obj))
+
         regions = []
         componentRegion = braille.Component(obj, text)
         regions.append(componentRegion)
@@ -885,7 +893,7 @@ class BrailleGenerator:
         else:
             text = util.appendString(text, "& y")
 
-        if obj == orca.locusOfFocus:
+        if obj == orca_state.locusOfFocus:
             text = util.appendString(text, self._getTextForRole(obj))
             text = util.appendString(text, self._getTextForAvailability(obj))
             text = util.appendString(text,
@@ -1032,7 +1040,11 @@ class BrailleGenerator:
                     break
 
         if len(regions) == 0:
-            if settings.readTableCellRow:
+            # Adding in a check here to make sure that the parent is a
+            # valid table. It's possible that the parent could be a
+            # table cell too (see bug #351501).
+            #
+            if settings.readTableCellRow and obj.parent.table:
                 rowRegions = []
                 savedBrailleVerbosityLevel = settings.brailleVerbosityLevel
                 settings.brailleVerbosityLevel = \
@@ -1054,7 +1066,7 @@ class BrailleGenerator:
                            ((row == 0 or row == parent.table.nRows-1) and \
                             parent.lastColumn == column)
 
-                if speakAll == True:
+                if speakAll:
                     focusRowRegion = None
                     for i in range(0, parent.table.nColumns):
                         accRow = parent.table.getAccessibleAt(row, i)
