@@ -21,9 +21,9 @@
 """Provides a methods that converts the role name of an Accessible
 object into localized strings for speech and braille."""
 
-__id__        = "$Id: rolenames.py,v 1.25 2006/06/10 00:54:47 wwalker Exp $"
-__version__   = "$Revision: 1.25 $"
-__date__      = "$Date: 2006/06/10 00:54:47 $"
+__id__        = "$Id: rolenames.py 1163 2006-07-13 13:46:48Z wwalker $"
+__version__   = "$Revision: 1163 $"
+__date__      = "$Date: 2006-07-13 09:46:48 -0400 (Thu, 13 Jul 2006) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -370,7 +370,7 @@ rolenames[ROLE_RADIO_BUTTON] = Rolename(ROLE_RADIO_BUTTON,
 
 rolenames[ROLE_RADIO_MENU_ITEM] = Rolename(ROLE_RADIO_MENU_ITEM,
                                            _("rdmnuitm"),
-                                           _("RadioMenuItem"),
+                                           _("RadioItem"),
                                            _("radio menu item"))
 
 rolenames[ROLE_RADIO_MENU] = Rolename(ROLE_RADIO_MENU,
